Add default context alltoall API (#350)

This commit is contained in:
Yiltan
2025-12-10 11:43:15 -05:00
committed by GitHub
szülő 1a16b3bedc
commit fddbe7b15d
4 fájl változott, egészen pontosan 69 új sor hozzáadva és 9 régi sor törölve
@@ -95,6 +95,44 @@ __device__ ATTR_NO_INLINE void rocshmem_ctx_ulonglong_alltoall_wg(
rocshmem_ctx_t ctx, rocshmem_team_t team, unsigned long long *dest,
const unsigned long long *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_float_alltoall_wg(
rocshmem_team_t team, float *dest, const float *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_double_alltoall_wg(
rocshmem_team_t team, double *dest, const double *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_char_alltoall_wg(
rocshmem_team_t team, char *dest, const char *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_schar_alltoall_wg(
rocshmem_team_t team, signed char *dest, const signed char *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_short_alltoall_wg(
rocshmem_team_t team, short *dest, const short *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_int_alltoall_wg(
rocshmem_team_t team, int *dest, const int *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_long_alltoall_wg(
rocshmem_team_t team, long *dest, const long *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_longlong_alltoall_wg(
rocshmem_team_t team, long long *dest, const long long *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_uchar_alltoall_wg(
rocshmem_team_t team, unsigned char *dest, const unsigned char *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_ushort_alltoall_wg(
rocshmem_team_t team, unsigned short *dest, const unsigned short *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_uint_alltoall_wg(
rocshmem_team_t team, unsigned int *dest, const unsigned int *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_ulong_alltoall_wg(
rocshmem_team_t team, unsigned long *dest, const unsigned long *source, int nelems);
__device__ ATTR_NO_INLINE void rocshmem_ulonglong_alltoall_wg(
rocshmem_team_t team, unsigned long long *dest, const unsigned long long *source, int nelems);
/**
* @name SHMEM_BROADCAST